#
# spec file for package arandr
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
# Copyright (c) 2013,2019 B1 Systems GmbH, Vohburg, Germany <seife+obs@b1-systems.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           arandr
Version:        0.1.11
Release:        3.2
Summary:        Visual Front End for XRandR
License:        GPL-3.0-only
URL:            https://christian.amsuess.com/tools/arandr/
Source:         http://christian.amsuess.com/tools/arandr/files/%{name}-%{version}.tar.gz
Patch1:         arandr-fix_desktop_icon.patch
BuildRequires:  gobject-introspection
BuildRequires:  make
BuildRequires:  python3
BuildRequires:  python3-docutils
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-pycairo
BuildRequires:  update-desktop-files
BuildArch:      noarch
%if 0%{?suse_version} >= 1220
Requires:       xrandr
%else
Requires:       xorg-x11
%endif

%description
ARandR is designed to provide a simple visual front end for XRandR. Relative
monitor positions are shown graphically and can be changed in a drag-and-drop
way.

%prep
%autosetup -p0

%build
python3 ./setup.py build

%install
python3 ./setup.py install \
    --prefix="%{_prefix}" \
    --root=%{buildroot}

# removed obsolete suse_update_desktop_file
#suse_update_desktop_file -r "${name}" Settings DesktopSettings
# all it did was this, which doesn't look substantial
#-Categories=Settings;HardwareSettings;
#+Categories=Settings;DesktopSettings;

%find_lang "%{name}"

chmod 0755 "%{buildroot}%{_bindir}"/*

%files -f "%{name}.lang"
%license COPYING
%doc ChangeLog NEWS README TODO
%{_bindir}/%{name}
%{_bindir}/unxrandr
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/unxrandr.1%{?ext_man}
%{python3_sitelib}/screenlayout/
%{python3_sitelib}/arandr-%{version}-py*.egg-info

%changelog
* Tue Jul 16 2024 Stefan Seyfried <seife+obs@b1-systems.com>
- remove obsolete suse_update_desktop_file macro
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build: autosetup -p0 for this package
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Jan 16 2023 Dirk Müller <dmueller@suse.com>
- update to 0.1.11:
  * Fix compatibility with Python 3.11 (by Rowan Hart)
* Tue Jun  2 2020 Michael Vetter <mvetter@suse.com>
- boo#1172370 arandr fails to start in TW and 15.1:
  Add BR on gobject-introspection and Requires on python3-gobject-Gdk
* Sun Dec 15 2019 Stefan Seyfried <seife+obs@b1-systems.com>
- update arandr-fix_desktop_icon.patch: use "video-display" icon
  instead of no longer existent "package_utility_desktop" to fix
  build on factory.
- drop desktop-data and hicolor-icon-theme buildrequires, they are
  no longer needed because "video-display" is a whitelisted name
  in brp-desktop.data
* Sun Oct 13 2019 Avindra Goolcharan <avindra@opensuse.org>
- Update to version 0.1.10:
  * package has been ported to Python 3 and GTK 3
  * 9 new laguages, and updates to existing i18n
* Wed Mar 21 2018 seife+obs@b1-systems.com
- BuildRequire desktop-data instead of desktop-data-openSUSE to
  fix build on SLES
* Wed Mar  2 2016 mvetter@suse.com
- Update to version 0.1.9:
  * XRandR version 1.5 is accepted
  * Translations were added (Albanian) and updated
* Thu Jul 16 2015 mvetter@suse.com
- Cleanup spec
- Update to version 0.1.8
  * Add support for choosing the primary output
  * Use "save" button in the file-save dialog
  * Update and add a lot of new languages
* Mon Mar 18 2013 cfarrell@suse.com
- license update: GPL-3.0
  Look at screenlayout/gui.py ; Fedora also use GPLv3 (their equivalent)
  for this package
* Tue Mar  5 2013 seife+obs@b1-systems.com
- don't buildrequire xorg-x11 (not needed)
- require xrandr instead of xorg-x11 on 12.2+ and python-gtk
* Tue Mar  5 2013 seife+obs@b1-systems.com
- update to version 0.1.7.1
  * fix AttributeError when modes with same name have different
    resolutions
  * show the entire output submenu as disabled instead of the
    "Active" checkbox
- obsoleted upstream patch removed
* Sat Mar  2 2013 seife+obs@b1-systems.com
- update to version 0.1.7
  * Fix the 'primary' issue
  - ignores the primary keyword
  - makes ARandR compatible with xrandr 1.4.0
  * Merged parts of the cglita branch
  - solves ValueError / "1080p" issue
  * New translations:
  - Ukrainian (by Rax Garfield)
  - Hungarian (by Tamás Nagy)
  - Greek (by Dimitris Giouroukis)
  - Korean (by ParkJS)
  * Updated translations:
  - Lithuanian (by Mantas Kriaučiūnas)
- add upstream patch to disable unconnected outputs
* Mon Dec  3 2012 pascal.bleser@opensuse.org
- initial version (0.1.6)
